C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_SET_SPOTB    **
C**************************
C
C
CD-Doc:
C SPOT_Border      SUBROUTINE LDM_SET_SPOTB (IPACK, IPLATE, VALUE, 
C                 +                          IERR, ERRSTR)
CD-end
      SUBROUTINE LDM_SET_SPOTB(IPACK, IPLATE, VALUE, IERR, ERRSTR)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Set value of plate dependent real parameter SPOT_BORDER
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      INTEGER IPACK
      INTEGER IPLATE
      REAL    VALUE
      INTEGER IERR
      CHARACTER*(*) ERRSTR

C  IPACK     (R)   Pack number, 0=all packs
C  IPLATE    (R)   Plate number, 0=all plates
C  VALUE     (R)   Width of spot background border (pixels) >0.0
C  IERR      (W)   Error flag =0 OK
C                             =-1 Invalid pack number
C                             =-2 Invalid plate number
C                             =3 Value must be >0.0
C  ERRSTR    (W)   Error description string if error found
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      INCLUDE 'ldm_lrl.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      IERR = 0
      ERRSTR = ' '
      CALL LDM_CHK_SPL (IPACK, IPLATE, IERR, ERRSTR)
      IF (IERR.NE.0) RETURN
      CALL LDM_ERR_R (VALUE, 2, 0.0, 0.0, 2, IERR, ERRSTR)
      IF (IERR.NE.0) RETURN
      CALL LDM_SETF_PL (IPACK, IPLATE, SPOTB, IS_SPOTB, CH_SPOTB,
     +                  ND_SPOTB, VALUE, LDM_MAXPK, LDM_MAXPL)
      CALL LDM_CLR_GEN (IPACK, IPLATE, 3)
      RETURN
      END
